@@ -23,6 +23,7 @@ def regex_from_word(word):
 def make_escaper(badchars):
     """Creates an efficient escape function that strips the given characters from the string."""
     translation_table = dict((ord(c), None) for c in badchars)
+    translation_table[ord("'")] = "''"
     def escaper(text):
         return force_text(text, errors="ignore").translate(translation_table)
     return escaper
@@ -321,7 +322,7 @@ class PostgresPrefixLegacySearchBackend(RegexSearchMixin, PostgresLegacySearchBa
     """
         
 
-escape_mysql_boolean_query_chars = make_escaper("+-<>()*\"")
+escape_mysql_boolean_query_chars = make_escaper("+-<>()*\".!:,;")
 
 def escape_mysql_boolean_query(search_text):
     return " ".join(
