@@ -1,10 +1,12 @@
 """Models used by django-watson."""
 
+from __future__ import unicode_literals
+
+import json
+
 from django.db import models
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
-from django.utils import simplejson as json
-
 
 def has_int_pk(model):
     """Tests whether the given model has an integer primary key."""
@@ -85,4 +87,4 @@ class SearchEntry(models.Model):
         return self.title
         
     class Meta:
-        verbose_name_plural = "search entries"
\ No newline at end of file
+        verbose_name_plural = "search entries"
